| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
UnliftIO.AutoUpdate.Thread
Contents
Synopsis
- mkAutoUpdate :: MonadUnliftIO m => UpdateSettings m a -> m (m a)
- mkAutoUpdateWithModify :: MonadUnliftIO m => UpdateSettings m a -> (a -> m a) -> m (m a)
Creation
mkAutoUpdate :: MonadUnliftIO m => UpdateSettings m a -> m (m a) Source #
Generate an action which will either read from an automatically updated value, or run the update action in the current thread.
Since: 0.1.0
mkAutoUpdateWithModify :: MonadUnliftIO m => UpdateSettings m a -> (a -> m a) -> m (m a) Source #
Generate an action which will either read from an automatically updated value, or run the update action in the current thread if the first time or the provided modify action after that.
Since: 0.1.0